import sns = require('@aws-cdk/aws-sns');
import { Construct } from '@aws-cdk/cdk';
/**
 * Options for URL subscriptions.
 */
export interface UrlSubscriptionProps {
    /**
     * The message to the queue is the same as it was sent to the topic
     *
     * If false, the message will be wrapped in an SNS envelope.
     *
     * @default false
     */
    readonly rawMessageDelivery?: boolean;
}
/**
 * Use a URL as a subscription target
 *
 * The message will be POSTed to the given URL.
 *
 * @see https://docs.aws.amazon.com/sns/latest/dg/sns-http-https-endpoint-as-subscriber.html
 */
export declare class UrlSubscription implements sns.ITopicSubscription {
    private readonly url;
    private readonly props;
    constructor(url: string, props?: UrlSubscriptionProps);
    bind(scope: Construct, topic: sns.ITopic): void;
}
